==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_pool.lua <==
function E0090()
    MNA()CMU("forest")FAI(0)
end
function E0091()
    MNA()CMU("forest")FAI(1)
end
function E0092()
    MNA()CMU("forest")FAI(2)
end
function E0093()
    MNA()CMU("forest")FAI(3)
end
function E0094()
    MNA()CMU("forest")FAI(4)
end

function GoCave()
    PRI()FAO(3)TRA("CS_cave","E0091",59,16)
end

function Door_GoPoolSmallRoom()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPoolSmallRoom",0,1)FAO(0)TRA("CS_pool_smallroom","E0092",21,14)
end

--钓鱼
function Fishing3()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("\nIt's a timid Red Fish...")NOD()CLR()
        ITP("Redfish")
        GIT("Redfish")
        SOU("CS_038_get_item")
        DNP("Fishing3")
        FLP("Fishing3")
        CMU("CS_Fanfale1")
        CAT("\nGot a =RED FISH=.")WAI(160)NOD()
        RMU()
    end
end

--Fishing
function Fishing4()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("\nIt's a Blue Fish commonly found in wild lakes...")NOD()CLR()
        ITP("Bluefish")
        GIT("Bluefish")
        SOU("CS_038_get_item")
        DNP("Fishing4")
        FLP("Fishing4")
        CMU("CS_Fanfale1")
        CAT("\nGot a =BLUE FISH=.")WAI(160)NOD()
        RMU()
    end
end

--Fishing key
function RustKey()
    PRI()
    MS4("\nIt's a rusty key...")NOD()CLR()
    ITP("RustKey")
    GIT("RustKey")
    SOU("CS_038_get_item")
    DNP("RustKey")
    FLP("RustKey")
    CMU("CS_Fanfale1")
    CAT("\nGot =RUSTY KEY=.")WAI(160)NOD()
    RMU()
end

==> ocstore25_7_4.zip: OcStore/Prgm/data/language/en-us/script/CS_pool.lua <==
function E0090()
    MNA()CMU("forest")FAI(0)
end
function E0091()
    MNA()CMU("forest")FAI(1)
end
function E0092()
    MNA()CMU("forest")FAI(2)
end
function E0093()
    MNA()CMU("forest")FAI(3)
end
function E0094()
    MNA()CMU("forest")FAI(4)
end

function GoCave()
    PRI()FAO(3)TRA("CS_cave","E0091",59,16)
end

function Door_GoPoolSmallRoom()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoPoolSmallRoom",0,1)FAO(0)TRA("CS_pool_smallroom","E0092",21,14)
end

--钓鱼
function Fishing3()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("\nIt's a timid Red Fish...")NOD()CLR()
        ITP("Redfish")
        GIT("Redfish")
        SOU("CS_038_get_item")
        DNP("Fishing3")
        FLP("Fishing3")
        CMU("CS_Fanfale1")
        CAT("\nGot a =RED FISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

--Fishing
function Fishing4()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("\nIt's a Blue Fish commonly found in wild lakes...")NOD()CLR()
        ITP("Bluefish")
        GIT("Bluefish")
        SOU("CS_038_get_item")
        DNP("Fishing4")
        FLP("Fishing4")
        CMU("CS_Fanfale1")
        CAT("\nGot a =BLUE FISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

--钓鱼（普通）
function Fishing5_Normal()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("\nIt's a Blue Fish commonly found in wild lakes...")NOD()CLR()
        ITP("Bluefish")
        GIT("Bluefish")
        SOU("CS_038_get_item")
        DNP("Fishing5_Normal")
        FLP("Fishing5_Normal")
        CMU("CS_Fanfale1")
        CAT("\nGot a =BLUE FISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

--Fishing key
function RustKey()
    PRI()
    MS4("\nIt's a rusty key...")NOD()CLR()
    ITP("RustKey")
    GIT("RustKey")
    SOU("CS_038_get_item")
    DNP("RustKey")
    FLP("RustKey")
    CMU("CS_Fanfale1")
    CAT("\nGot =RUSTY KEY=.")WAI(160)NOD()
    RMU()
end
